@@ -316,7 +316,7 @@ def PySconsSetup(env=None, args=ARGUMENTS, tools=['default', PYTOOL()]):
     import SCons.Node
     files = set(targets)
     for t in targets:
-        W = SCons.Node.Walker(env.lookup_list[t])
+        W = SCons.Node.Walker(env.Entry(t))
         while not W.is_done():
             N = W.get_next()
             try:
